<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class HeroController extends Controller
{
    public function show($id = null)
    {
        if (is_null($id)) {
            return view('home')->with('message', 'No ID provided. Please provide a valid worksheet ID.');
        }

        // Fetch the data from the worksheets table using the new connection
        $worksheetData = DB::connection('sqlite_worksheet')->table('worksheets')->where('id', $id)->first();

        // Check if the data exists
        if ($worksheetData) {
            // Process the data as needed
            $name = htmlspecialchars($worksheetData->name);
            $image_names = explode(',', $worksheetData->photo_gallery_file_names);
            $gallery_no = intval($worksheetData->photo_gallery);

            // Check if there are at least two images
            $first_image_name = $image_names[0] ?? null;
            $second_image_name = $image_names[1] ?? null;

            // Generate image paths
            $first_image_path = $first_image_name ? url('https://ricardoamigo.com/assets/rental_imgs/' . $gallery_no . '/' . $first_image_name) : null;
            $second_image_path = $second_image_name ? url('https://ricardoamigo.com/assets/rental_imgs/' . $gallery_no . '/' . $second_image_name) : null;

            $agent_id  = htmlspecialchars($worksheetData->agent);


            // Fetch agent details from the remote JSON file using cURL
            $url = 'https://ricardoamigo.com/exports/bios_export.json';
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);

            $response = curl_exec($ch);
            if (curl_errno($ch)) {
                // Handle error
                $error_msg = curl_error($ch);
                curl_close($ch);
                return view('home')->with('message', 'Failed to fetch agent details. Error: ' . $error_msg);
            }
            curl_close($ch);

            $agents = json_decode($response, true);

            // Find the agent's name using the agent ID
            $agent_name = null;
            $agent_photo = null;
            $agent_phone = null;
            $agent_whatsapp = null;
            $agent_email = null;
            $agent_bio_en = null;
            foreach ($agents as $agent) {
                if ($agent['id'] == $agent_id) {
                    $agent_name = $agent['name'];
                    $agent_photo = $agent['photo'];
                    $agent_phone = $agent['phone'];
                    $agent_whatsapp = $agent['whatsapp'];
                    $agent_email = $agent['email'];
                    $agent_bio_en = $agent['bio_en'];
                    break;
                }
            }

            // Pass the paths and agent's name to the view
            return view('home', compact('name', 'first_image_path', 'second_image_path', 'worksheetData', 'id', 'agent_name', 'agent_photo', 'agent_phone', 'agent_whatsapp', 'agent_email', 'agent_bio_en'));
        } else {
            return view('home')->with('message', 'No data found for the provided ID.');
        }
    }
}
